// AUTOGENERATED FILE - DO NOT MODIFY!
// This file generated by Djinni from com_verifone_commerce_payment.djinni

#import <Foundation/Foundation.h>
@class VFIAmountTotals;
@class VFIBasket;
@class VFIBasketEvent;
@class VFIDonation;
@class VFIMerchandise;
@class VFIModifier;
@class VFIOffer;


/**
 * The manager for the basket attached to a transaction. This is used when a basket 
 * is involved in a transaction, but is not required to process a simple sale.
 */
@interface VFIBasketManager : NSObject

/** Returns the session Id associated with this basket. */
- (nonnull NSString *)getSessionId;

/**
 * Allows attaching a pre-existing basket to the current transaction. This 
 * returns an error if a basket has already been opened and has items.
 * @param basket The pre-existing basket.
 * @param amountTotals The total running amounts to display on the
 * customer-facing screen. This is a required field.
 * @return The status indicating success or failure.
 */
- (nullable VFIBasketEvent *)registerBasket:(nullable VFIBasket *)basket
                                     totals:(nullable VFIAmountTotals *)totals;

/**
 * Lets the payment application know that the POS has finished with the initial 
 * basket and can allow other applications to make adjustments via the 
 * REQUEST_BASKET_ADJUSTMENT trigger. The attached transaction listeners will 
 * be notified if any changes are made, and can respond with a finalized basket 
 * directly to the event. After closing the basket, no further actions
 * should be performed on it using the basket manager.
 * @return The status indicating success or failure.
 */
- (nullable VFIBasketEvent *)finalizeBasket;

/**
 * Removes all items in the basket and resets the basket state to open.
 * @return The status indicating success or failure.
 */
- (nullable VFIBasketEvent *)purgeBasket;

/**
 * Returns the current basket that is associated with the transaction.
 * @return The current basket for the transaction.
 */
- (nullable VFIBasket *)getBasket;

/** Returns the current tracked Amount Totals. */
- (nullable VFIAmountTotals *)getCurrentAmountTotals;

/**
 * Adds the items to the basket, notifying listening applications and updating 
 * the display.
 * @param merchandise The items to add to the basket.
 * @param amountTotals The total running amounts to display on the
 * customer-facing screen. This is a required field.
 * @return The status indicating if the item was successfully added after 
 * sending the add request to the display. This does not return information 
 * regarding the display.
 */
- (nullable VFIBasketEvent *)addMerchandise:(nonnull NSArray<VFIMerchandise *> *)merchandise
                               amountTotals:(nullable VFIAmountTotals *)amountTotals;

/**
 * Removes the items from the basket, notifying listening applications and 
 * updating the display. Uses the Basket Item ID to remove the proper items.
 * @param merchandise The items to remove.
 * @param amountTotals The total running amounts to display on the
 * customer-facing screen. This is a required field.
 * @return The status indicating if the item was successfully removed after 
 * sending the removal request to the display. This does not return information 
 * regarding the display.
 */
- (nullable VFIBasketEvent *)removeMerchandise:(nonnull NSArray<VFIMerchandise *> *)merchandise
                                  amountTotals:(nullable VFIAmountTotals *)amountTotals;

/**
 * Modifies the items in the basket, notifying listening applications and 
 * updating the display. Uses the Basket Item ID to apply the new values.
 * @param merchandise The items to modify with the new values, but containing 
 * the existing Basket Item ID.
 * @param amountTotals The total running amounts to display on the
 * customer-facing screen. This is a required field.
 * @return The status indicating if the modification was successfully sent to 
 * the display.  This does not return information regarding the display.
 */
- (nullable VFIBasketEvent *)modifyMerchandise:(nonnull NSArray<VFIMerchandise *> *)merchandise
                                  amountTotals:(nullable VFIAmountTotals *)amountTotals;

/**
 * Adds a modifier to an existing merchandise object.
 * @param modifier The modifer to add to this merchandise object. 
 * @param merchandise The items to modify with the new values, but containing 
 * the existing Basket Item ID.
 * @param amountTotals The total running amounts to display on the
 * customer-facing screen. This is a required field.
 */
- (nullable VFIBasketEvent *)addModifierToMerchandise:(nullable VFIModifier *)modifier
                                          merchandise:(nullable VFIMerchandise *)merchandise
                                         amountTotals:(nullable VFIAmountTotals *)amountTotals;

/**
 * Removes a modifier from an existing merchandise object.
 * @param modifier The modifer to remove from this merchandise object. 
 * @param merchandise The items to modify with the new values, but containing 
 * the existing Basket Item ID.
 * @param amountTotals The total running amounts to display on the
 * customer-facing screen. This is a required field.
 */
- (nullable VFIBasketEvent *)removeModifierFromMerchandise:(nullable VFIModifier *)modifier
                                               merchandise:(nullable VFIMerchandise *)merchandise
                                              amountTotals:(nullable VFIAmountTotals *)amountTotals;

/**
 * add offers (coupons, discounts, loyalty, etc.) to the existing basket object.
 * @param offers The list of offers to be added to the basket.
 * @param amountTotals The total running amounts to display on the
 * customer-facing screen. This is a required field.
 */
- (nullable VFIBasketEvent *)addOffers:(nonnull NSArray<VFIOffer *> *)offers
                          amountTotals:(nullable VFIAmountTotals *)amountTotals;

/**
 * remove offers (coupons, discounts, loyalty, etc.) from the existing basket 
 * object.
 * @param offers The list of offers to be removed from the basket.
 * @param amountTotals The total running amounts to display on the
 * customer-facing screen. This is a required field.
 */
- (nullable VFIBasketEvent *)removeOffers:(nonnull NSArray<VFIOffer *> *)offers
                             amountTotals:(nullable VFIAmountTotals *)amountTotals;

/**
 * modify offers (coupons, discounts, loyalty, etc.) attached to the existing 
 * basket object.
 * @param offers The list of offers to be modified in the basket.
 * @param amountTotals The total running amounts to display on the
 * customer-facing screen. This is a required field.
 */
- (nullable VFIBasketEvent *)modifyOffers:(nonnull NSArray<VFIOffer *> *)offers
                             amountTotals:(nullable VFIAmountTotals *)amountTotals;

/**
 * add donations to the existing basket object.
 * @param offers The list of donationss to be added to the basket.
 * @param amountTotals The total running amounts to display on the
 * customer-facing screen. This is a required field.
 */
- (nullable VFIBasketEvent *)addDonations:(nonnull NSArray<VFIDonation *> *)donations
                             amountTotals:(nullable VFIAmountTotals *)amountTotals;

/**
 * remove donations from the existing basket object.
 * @param offers The list of donations to be removed from the basket.
 * @param amountTotals The total running amounts to display on the
 * customer-facing screen. This is a required field.
 */
- (nullable VFIBasketEvent *)removeDonations:(nonnull NSArray<VFIDonation *> *)donations
                                amountTotals:(nullable VFIAmountTotals *)amountTotals;

/**
 * modify donations attached to the existing basket object.
 * @param offers The list of donations to be modified in the basket.
 * @param amountTotals The total running amounts to display on the
 * customer-facing screen. This is a required field.
 */
- (nullable VFIBasketEvent *)modifyDonations:(nonnull NSArray<VFIDonation *> *)donations
                                amountTotals:(nullable VFIAmountTotals *)amountTotals;

@end
